@@ -179,9 +179,9 @@ test_that("vc function functions correctly", {
 
   vcVCLm <- vc(geVCLm)
   expect_is(vcVCLm, "data.frame")
-  expect_named(vcVCLm, "component")
+  expect_named(vcVCLm, "Component")
   expect_equal(rownames(vcVCLm), c("genotype", "residuals"))
-  expect_equal(vcVCLm[["component"]],
+  expect_equal(vcVCLm[["Component"]],
                c(78.7850079727369, 309.69339127849))
 
   skip_on_cran()
@@ -189,9 +189,9 @@ test_that("vc function functions correctly", {
   geVCAs <- gxeVarComp(TD = BLUEs, trait = "t1", engine = "asreml")
   vcVCAs <- vc(geVCAs)
   expect_is(vcVCAs, "data.frame")
-  expect_named(vcVCAs, c("component", "stdError"))
+  expect_named(vcVCAs, c("Component", "SE"))
   expect_equal(rownames(vcVCAs), c("genotype", "residuals"))
-  expect_equal(vcVCAs[["component"]],
+  expect_equal(vcVCAs[["Component"]],
                c(78.7960647165854, 309.736936464321))
 })
 
